"""
Canonical terminal names and TERM/TERM_PROGRAM aliases.

This code generated by python wcwidth using ucs-detect project data.

Terminal multiplexers (tmux, zellij, libvterm, screen) are excluded because their displayed
presentation depends on the host terminal; cursor-position reports from ucs-detect testing are not
reliable indicators of actual width.
"""
# pylint: skip-file

KNOWN_TERMINALS = frozenset({
    'alacritty',
    'apple_terminal',
    'bobcat',
    'contour',
    'extraterm',
    'foot',
    'ghostty',
    'iterm2',
    'kitty',
    'konsole',
    'mintty',
    'mlterm',
    'pterm',
    'rio',
    'st',
    'terminology',
    'urxvt',
    'vte',
    'warp',
    'wezterm',
    'xterm',
    'xterm.js',
})

ALIASES = {
    'hyper': 'xterm.js',
    'iterm.app': 'iterm2',
    'putty': 'pterm',
    'rxvt': 'urxvt',
    'rxvt-unicode-256color': 'urxvt',
    'st-256color': 'st',
    'tabby': 'xterm.js',
    'vscode': 'xterm.js',
    'warpterminal': 'warp',
    'xterm-ghostty': 'ghostty',
    'xterm-kitty': 'kitty',
}
