"""
Exports function list_versions() for unicode version level support.

This code generated by python wcwidth project.
"""

from __future__ import annotations


def list_versions() -> tuple[str, ...]:
    """
    Return Unicode version levels supported by this module release.

    .. versionchanged:: 0.5.0
       Now returns a single-element tuple containing only the latest version.

    :returns: Supported Unicode version numbers in ascending sorted order.
    """
    return (
        "17.0.0",
    )
