"""
Terminal override tables keyed by canonical terminal software name.

This code generated by python wcwidth using ucs-detect project data.
"""
# pylint: skip-file
from __future__ import annotations

# For terminals: rio
_SET_WIDE_OVERRIDES_243C8ED7: dict[str, tuple[tuple[int, int], ...]] = {
    'narrower': (
        (0x1f1e6, 0x1f1ff,),  # Regional Indicator Symbo..Regional Indicator Symbo
        (0x1f6d8, 0x1f6d8,),  # Landslide
        (0x1fa8a, 0x1fa8a,),  # Trombone
        (0x1fa8e, 0x1fa8e,),  # Treasure Chest
        (0x1fac8, 0x1fac8,),  # Hairy Creature
        (0x1facd, 0x1facd,),  # Orca
        (0x1faea, 0x1faea,),  # Distorted Face
        (0x1faef, 0x1faef,),  # Fight Cloud
    ),
}

# For terminals: konsole
_SET_WIDE_OVERRIDES_25894E07: dict[str, tuple[tuple[int, int], ...]] = {
    'narrower': (
        (0x02630, 0x02637,),  # Trigram For Heaven      ..Trigram For Earth
        (0x0268a, 0x0268f,),  # Monogram For Yang       ..Digram For Greater Yin
        (0x02ffc, 0x02fff,),  # Ideographic Description ..Ideographic Description
        (0x031e4, 0x031e5,),  # Cjk Stroke Hxg          ..Cjk Stroke Szp
        (0x031ef, 0x031ef,),  # Ideographic Description Character Subtraction
        (0x04dc0, 0x04dff,),  # Hexagram For The Creativ..Hexagram For Before Comp
        (0x1d300, 0x1d356,),  # Monogram For Earth      ..Tetragram For Fostering
        (0x1d360, 0x1d376,),  # Counting Rod Unit Digit ..Ideographic Tally Mark F
        (0x1f6d8, 0x1f6d8,),  # Landslide
        (0x1fa89, 0x1fa8a,),  # Harp                    ..Trombone
        (0x1fa8e, 0x1fa8f,),  # Treasure Chest          ..Shovel
        (0x1fabe, 0x1fabe,),  # Leafless Tree
        (0x1fac6, 0x1fac6,),  # Fingerprint
        (0x1fac8, 0x1fac8,),  # Hairy Creature
        (0x1facd, 0x1facd,),  # Orca
        (0x1fadc, 0x1fadc,),  # Root Vegetable
        (0x1fadf, 0x1fadf,),  # Splatter
        (0x1fae9, 0x1faea,),  # Face With Bags Under Eye..Distorted Face
        (0x1faef, 0x1faef,),  # Fight Cloud
    ),
}

# For terminals: extraterm
_SET_WIDE_OVERRIDES_6C1578E8: dict[str, tuple[tuple[int, int], ...]] = {
    'narrower': (
        (0x02630, 0x02637,),  # Trigram For Heaven      ..Trigram For Earth
        (0x0268a, 0x0268f,),  # Monogram For Yang       ..Digram For Greater Yin
        (0x02ffc, 0x02fff,),  # Ideographic Description ..Ideographic Description
        (0x031e4, 0x031e5,),  # Cjk Stroke Hxg          ..Cjk Stroke Szp
        (0x031ef, 0x031ef,),  # Ideographic Description Character Subtraction
        (0x04dc0, 0x04dff,),  # Hexagram For The Creativ..Hexagram For Before Comp
        (0x1d300, 0x1d356,),  # Monogram For Earth      ..Tetragram For Fostering
        (0x1d360, 0x1d376,),  # Counting Rod Unit Digit ..Ideographic Tally Mark F
        (0x1f1e6, 0x1f1ff,),  # Regional Indicator Symbo..Regional Indicator Symbo
        (0x1f6d8, 0x1f6d8,),  # Landslide
        (0x1f6dc, 0x1f6dc,),  # Wireless
        (0x1fa75, 0x1fa77,),  # Light Blue Heart        ..Pink Heart
        (0x1fa87, 0x1fa8a,),  # Maracas                 ..Trombone
        (0x1fa8e, 0x1fa8f,),  # Treasure Chest          ..Shovel
        (0x1faad, 0x1faaf,),  # Folding Hand Fan        ..Khanda
        (0x1fabb, 0x1fabf,),  # Hyacinth                ..Goose
        (0x1fac6, 0x1fac6,),  # Fingerprint
        (0x1fac8, 0x1fac8,),  # Hairy Creature
        (0x1facd, 0x1facf,),  # Orca                    ..Donkey
        (0x1fada, 0x1fadc,),  # Ginger Root             ..Root Vegetable
        (0x1fadf, 0x1fadf,),  # Splatter
        (0x1fae8, 0x1faea,),  # Shaking Face            ..Distorted Face
        (0x1faef, 0x1faef,),  # Fight Cloud
        (0x1faf7, 0x1faf8,),  # Leftwards Pushing Hand  ..Rightwards Pushing Hand
    ),
}

# For terminals: alacritty, apple_terminal, pterm, st, urxvt, xterm
_SET_WIDE_OVERRIDES_6E5EF6CC: dict[str, tuple[tuple[int, int], ...]] = {
    'narrower': (
        (0x1f1e6, 0x1f1ff,),  # Regional Indicator Symbo..Regional Indicator Symbo
    ),
}

# For terminals: kitty
_SET_WIDE_OVERRIDES_73E5B60D: dict[str, tuple[tuple[int, int], ...]] = {
    'zeroer': (
        (0x1f3fb, 0x1f3ff,),  # Emoji Modifier Fitzpatri..Emoji Modifier Fitzpatri
    ),
}

# For terminals: mintty
_SET_WIDE_OVERRIDES_79ED351B: dict[str, tuple[tuple[int, int], ...]] = {
    'narrower': (
        (0x02630, 0x02637,),  # Trigram For Heaven      ..Trigram For Earth
        (0x0268a, 0x0268f,),  # Monogram For Yang       ..Digram For Greater Yin
        (0x02ffc, 0x02fff,),  # Ideographic Description ..Ideographic Description
        (0x031e4, 0x031e5,),  # Cjk Stroke Hxg          ..Cjk Stroke Szp
        (0x031ef, 0x031ef,),  # Ideographic Description Character Subtraction
        (0x04dc0, 0x04dff,),  # Hexagram For The Creativ..Hexagram For Before Comp
        (0x1d300, 0x1d356,),  # Monogram For Earth      ..Tetragram For Fostering
        (0x1d360, 0x1d376,),  # Counting Rod Unit Digit ..Ideographic Tally Mark F
        (0x1fa89, 0x1fa89,),  # Harp
        (0x1fa8f, 0x1fa8f,),  # Shovel
        (0x1fabe, 0x1fabe,),  # Leafless Tree
        (0x1fac6, 0x1fac6,),  # Fingerprint
        (0x1fadc, 0x1fadc,),  # Root Vegetable
        (0x1fadf, 0x1fadf,),  # Splatter
        (0x1fae9, 0x1fae9,),  # Face With Bags Under Eyes
    ),
}

# For terminals: bobcat
_SET_WIDE_OVERRIDES_8A2DF0C6: dict[str, tuple[tuple[int, int], ...]] = {
    'narrower': (
        (0x03030, 0x03030,),  # Wavy Dash
        (0x0303d, 0x0303d,),  # Part Alternation Mark
        (0x03297, 0x03297,),  # Circled Ideograph Congratulation
        (0x03299, 0x03299,),  # Circled Ideograph Secret
        (0x1f202, 0x1f202,),  # Squared Katakana Sa
        (0x1f237, 0x1f237,),  # Squared Cjk Unified Ideograph-6708
    ),
    'zeroer': (
        (0x1f3fb, 0x1f3ff,),  # Emoji Modifier Fitzpatri..Emoji Modifier Fitzpatri
    ),
}

# For terminals: foot
_SET_WIDE_OVERRIDES_98684D9B: dict[str, tuple[tuple[int, int], ...]] = {
    'narrower': (
        (0x1f1e6, 0x1f1ff,),  # Regional Indicator Symbo..Regional Indicator Symbo
        (0x1f3fb, 0x1f3ff,),  # Emoji Modifier Fitzpatri..Emoji Modifier Fitzpatri
    ),
}

# For terminals: xterm.js
_SET_WIDE_OVERRIDES_9D8AD458: dict[str, tuple[tuple[int, int], ...]] = {
    'narrower': (
        (0x02630, 0x02637,),  # Trigram For Heaven      ..Trigram For Earth
        (0x0268a, 0x0268f,),  # Monogram For Yang       ..Digram For Greater Yin
        (0x02ffc, 0x02fff,),  # Ideographic Description ..Ideographic Description
        (0x031bb, 0x031bf,),  # Bopomofo Final Letter G ..Bopomofo Letter Ah
        (0x031e4, 0x031e5,),  # Cjk Stroke Hxg          ..Cjk Stroke Szp
        (0x031ef, 0x031ef,),  # Ideographic Description Character Subtraction
        (0x04dc0, 0x04dff,),  # Hexagram For The Creativ..Hexagram For Before Comp
        (0x1aff0, 0x1aff3,),  # Katakana Letter Minnan T..Katakana Letter Minnan T
        (0x1aff5, 0x1affb,),  # Katakana Letter Minnan T..Katakana Letter Minnan N
        (0x1affd, 0x1affe,),  # Katakana Letter Minnan N..Katakana Letter Minnan N
        (0x1d300, 0x1d356,),  # Monogram For Earth      ..Tetragram For Fostering
        (0x1d360, 0x1d376,),  # Counting Rod Unit Digit ..Ideographic Tally Mark F
        (0x1f1e6, 0x1f1ff,),  # Regional Indicator Symbo..Regional Indicator Symbo
        (0x1f6d6, 0x1f6d8,),  # Hut                     ..Landslide
        (0x1f6dc, 0x1f6df,),  # Wireless                ..Ring Buoy
        (0x1f6fb, 0x1f6fc,),  # Pickup Truck            ..Roller Skate
        (0x1f7f0, 0x1f7f0,),  # Heavy Equals Sign
        (0x1f90c, 0x1f90c,),  # Pinched Fingers
        (0x1f972, 0x1f972,),  # Smiling Face With Tear
        (0x1f977, 0x1f979,),  # Ninja                   ..Face Holding Back Tears
        (0x1f9a3, 0x1f9a4,),  # Mammoth                 ..Dodo
        (0x1f9ab, 0x1f9ad,),  # Beaver                  ..Seal
        (0x1f9cb, 0x1f9cc,),  # Bubble Tea              ..Troll
        (0x1fa74, 0x1fa77,),  # Thong Sandal            ..Pink Heart
        (0x1fa7b, 0x1fa7c,),  # X-ray                   ..Crutch
        (0x1fa83, 0x1fa8a,),  # Boomerang               ..Trombone
        (0x1fa8e, 0x1fa8f,),  # Treasure Chest          ..Shovel
        (0x1fa96, 0x1fac6,),  # Military Helmet         ..Fingerprint
        (0x1fac8, 0x1fac8,),  # Hairy Creature
        (0x1facd, 0x1fadc,),  # Orca                    ..Root Vegetable
        (0x1fadf, 0x1faea,),  # Splatter                ..Distorted Face
        (0x1faef, 0x1faf8,),  # Fight Cloud             ..Rightwards Pushing Hand
    ),
}

# For terminals: vte, wezterm
_SET_WIDE_OVERRIDES_A5DF05D4: dict[str, tuple[tuple[int, int], ...]] = {
    'narrower': (
        (0x02630, 0x02637,),  # Trigram For Heaven      ..Trigram For Earth
        (0x0268a, 0x0268f,),  # Monogram For Yang       ..Digram For Greater Yin
        (0x02ffc, 0x02fff,),  # Ideographic Description ..Ideographic Description
        (0x031e4, 0x031e5,),  # Cjk Stroke Hxg          ..Cjk Stroke Szp
        (0x031ef, 0x031ef,),  # Ideographic Description Character Subtraction
        (0x04dc0, 0x04dff,),  # Hexagram For The Creativ..Hexagram For Before Comp
        (0x1d300, 0x1d356,),  # Monogram For Earth      ..Tetragram For Fostering
        (0x1d360, 0x1d376,),  # Counting Rod Unit Digit ..Ideographic Tally Mark F
        (0x1f1e6, 0x1f1ff,),  # Regional Indicator Symbo..Regional Indicator Symbo
        (0x1fa89, 0x1fa89,),  # Harp
        (0x1fa8f, 0x1fa8f,),  # Shovel
        (0x1fabe, 0x1fabe,),  # Leafless Tree
        (0x1fac6, 0x1fac6,),  # Fingerprint
        (0x1fadc, 0x1fadc,),  # Root Vegetable
        (0x1fadf, 0x1fadf,),  # Splatter
        (0x1fae9, 0x1fae9,),  # Face With Bags Under Eyes
    ),
}

# For terminals: terminology
_SET_WIDE_OVERRIDES_C908F105: dict[str, tuple[tuple[int, int], ...]] = {
    'narrower': (
        (0x02630, 0x02637,),  # Trigram For Heaven      ..Trigram For Earth
        (0x0268a, 0x0268f,),  # Monogram For Yang       ..Digram For Greater Yin
        (0x04dc0, 0x04dff,),  # Hexagram For The Creativ..Hexagram For Before Comp
        (0x0fada, 0x0faff,),  # (nil)
        (0x1d300, 0x1d356,),  # Monogram For Earth      ..Tetragram For Fostering
        (0x1d360, 0x1d376,),  # Counting Rod Unit Digit ..Ideographic Tally Mark F
        (0x1f1e6, 0x1f1ff,),  # Regional Indicator Symbo..Regional Indicator Symbo
        (0x1f6d8, 0x1f6d8,),  # Landslide
        (0x1f6dc, 0x1f6df,),  # Wireless                ..Ring Buoy
        (0x1f7f0, 0x1f7f0,),  # Heavy Equals Sign
        (0x1fad7, 0x1fadc,),  # Pouring Liquid          ..Root Vegetable
        (0x1fadf, 0x1faea,),  # Splatter                ..Distorted Face
        (0x1faef, 0x1faf8,),  # Fight Cloud             ..Rightwards Pushing Hand
    ),
}

# For terminals: ghostty, iterm2
_SET_WIDE_OVERRIDES_CF30CE25: dict[str, tuple[tuple[int, int], ...]] = {
    'zeroer': (
        (0x0115f, 0x0115f,),  # Hangul Choseong Filler
    ),
}

# For terminals: mlterm, warp
_SET_WIDE_OVERRIDES_D289A768: dict[str, tuple[tuple[int, int], ...]] = {
    'narrower': (
        (0x02630, 0x02637,),  # Trigram For Heaven      ..Trigram For Earth
        (0x0268a, 0x0268f,),  # Monogram For Yang       ..Digram For Greater Yin
        (0x031e4, 0x031e5,),  # Cjk Stroke Hxg          ..Cjk Stroke Szp
        (0x04dc0, 0x04dff,),  # Hexagram For The Creativ..Hexagram For Before Comp
        (0x1d300, 0x1d356,),  # Monogram For Earth      ..Tetragram For Fostering
        (0x1d360, 0x1d376,),  # Counting Rod Unit Digit ..Ideographic Tally Mark F
        (0x1f1e6, 0x1f1ff,),  # Regional Indicator Symbo..Regional Indicator Symbo
        (0x1f6d8, 0x1f6d8,),  # Landslide
        (0x1fa89, 0x1fa8a,),  # Harp                    ..Trombone
        (0x1fa8e, 0x1fa8f,),  # Treasure Chest          ..Shovel
        (0x1fabe, 0x1fabe,),  # Leafless Tree
        (0x1fac6, 0x1fac6,),  # Fingerprint
        (0x1fac8, 0x1fac8,),  # Hairy Creature
        (0x1facd, 0x1facd,),  # Orca
        (0x1fadc, 0x1fadc,),  # Root Vegetable
        (0x1fadf, 0x1fadf,),  # Splatter
        (0x1fae9, 0x1faea,),  # Face With Bags Under Eye..Distorted Face
        (0x1faef, 0x1faef,),  # Fight Cloud
    ),
}

WIDE_OVERRIDES: dict[str, dict[str, tuple[tuple[int, int], ...]]] = {
    'alacritty': _SET_WIDE_OVERRIDES_6E5EF6CC,
    'apple_terminal': _SET_WIDE_OVERRIDES_6E5EF6CC,
    'bobcat': _SET_WIDE_OVERRIDES_8A2DF0C6,
    'extraterm': _SET_WIDE_OVERRIDES_6C1578E8,
    'foot': _SET_WIDE_OVERRIDES_98684D9B,
    'ghostty': _SET_WIDE_OVERRIDES_CF30CE25,
    'iterm2': _SET_WIDE_OVERRIDES_CF30CE25,
    'kitty': _SET_WIDE_OVERRIDES_73E5B60D,
    'konsole': _SET_WIDE_OVERRIDES_25894E07,
    'mintty': _SET_WIDE_OVERRIDES_79ED351B,
    'mlterm': _SET_WIDE_OVERRIDES_D289A768,
    'pterm': _SET_WIDE_OVERRIDES_6E5EF6CC,
    'rio': _SET_WIDE_OVERRIDES_243C8ED7,
    'st': _SET_WIDE_OVERRIDES_6E5EF6CC,
    'terminology': _SET_WIDE_OVERRIDES_C908F105,
    'urxvt': _SET_WIDE_OVERRIDES_6E5EF6CC,
    'vte': _SET_WIDE_OVERRIDES_A5DF05D4,
    'warp': _SET_WIDE_OVERRIDES_D289A768,
    'wezterm': _SET_WIDE_OVERRIDES_A5DF05D4,
    'xterm': _SET_WIDE_OVERRIDES_6E5EF6CC,
    'xterm.js': _SET_WIDE_OVERRIDES_9D8AD458,
}

# For terminals: alacritty, apple_terminal, extraterm, foot, mlterm, pterm, rio, st, terminology, urxvt, vte, warp, wezterm, xterm, xterm.js
_SET_SRI_OVERRIDES_6E5EF6CC: dict[str, tuple[tuple[int, int], ...]] = {
    'narrower': (
        (0x1f1e6, 0x1f1ff,),  # Regional Indicator Symbo..Regional Indicator Symbo
    ),
}

SRI_OVERRIDES: dict[str, dict[str, tuple[tuple[int, int], ...]]] = {
    'alacritty': _SET_SRI_OVERRIDES_6E5EF6CC,
    'apple_terminal': _SET_SRI_OVERRIDES_6E5EF6CC,
    'extraterm': _SET_SRI_OVERRIDES_6E5EF6CC,
    'foot': _SET_SRI_OVERRIDES_6E5EF6CC,
    'mlterm': _SET_SRI_OVERRIDES_6E5EF6CC,
    'pterm': _SET_SRI_OVERRIDES_6E5EF6CC,
    'rio': _SET_SRI_OVERRIDES_6E5EF6CC,
    'st': _SET_SRI_OVERRIDES_6E5EF6CC,
    'terminology': _SET_SRI_OVERRIDES_6E5EF6CC,
    'urxvt': _SET_SRI_OVERRIDES_6E5EF6CC,
    'vte': _SET_SRI_OVERRIDES_6E5EF6CC,
    'warp': _SET_SRI_OVERRIDES_6E5EF6CC,
    'wezterm': _SET_SRI_OVERRIDES_6E5EF6CC,
    'xterm': _SET_SRI_OVERRIDES_6E5EF6CC,
    'xterm.js': _SET_SRI_OVERRIDES_6E5EF6CC,
}

# For terminals: bobcat, kitty
_SET_SFZ_OVERRIDES_73E5B60D: dict[str, tuple[tuple[int, int], ...]] = {
    'zeroer': (
        (0x1f3fb, 0x1f3ff,),  # Emoji Modifier Fitzpatri..Emoji Modifier Fitzpatri
    ),
}

# For terminals: foot
_SET_SFZ_OVERRIDES_8DDFF0C4: dict[str, tuple[tuple[int, int], ...]] = {
    'narrower': (
        (0x1f3fb, 0x1f3ff,),  # Emoji Modifier Fitzpatri..Emoji Modifier Fitzpatri
    ),
}

SFZ_OVERRIDES: dict[str, dict[str, tuple[tuple[int, int], ...]]] = {
    'bobcat': _SET_SFZ_OVERRIDES_73E5B60D,
    'foot': _SET_SFZ_OVERRIDES_8DDFF0C4,
    'kitty': _SET_SFZ_OVERRIDES_73E5B60D,
}

# For terminals: iterm2
_SET_VS16_OVERRIDES_82FD018F: dict[str, tuple[tuple[int, int], ...]] = {
    'narrower': (
        (0x00023, 0x00023,),  # Number Sign
        (0x0002a, 0x0002a,),  # Asterisk
        (0x00030, 0x00039,),  # Digit Zero              ..Digit Nine
    ),
}

# For terminals: alacritty, apple_terminal, contour, mlterm, pterm, st, terminology, urxvt, vte, wezterm, xterm, xterm.js
_SET_VS16_OVERRIDES_F48531B2: dict[str, tuple[tuple[int, int], ...]] = {
    'narrower': (
        (0x00023, 0x00023,),  # Number Sign
        (0x0002a, 0x0002a,),  # Asterisk
        (0x00030, 0x00039,),  # Digit Zero              ..Digit Nine
        (0x000a9, 0x000a9,),  # Copyright Sign
        (0x000ae, 0x000ae,),  # Registered Sign
        (0x0203c, 0x0203c,),  # Double Exclamation Mark
        (0x02049, 0x02049,),  # Exclamation Question Mark
        (0x02122, 0x02122,),  # Trade Mark Sign
        (0x02139, 0x02139,),  # Information Source
        (0x02194, 0x02199,),  # Left Right Arrow        ..South West Arrow
        (0x021a9, 0x021aa,),  # Leftwards Arrow With Hoo..Rightwards Arrow With Ho
        (0x02328, 0x02328,),  # Keyboard
        (0x023cf, 0x023cf,),  # Eject Symbol
        (0x023ed, 0x023ef,),  # Black Right-pointing Dou..Black Right-pointing Tri
        (0x023f1, 0x023f2,),  # Stopwatch               ..Timer Clock
        (0x023f8, 0x023fa,),  # Double Vertical Bar     ..Black Circle For Record
        (0x024c2, 0x024c2,),  # Circled Latin Capital Letter M
        (0x025aa, 0x025ab,),  # Black Small Square      ..White Small Square
        (0x025b6, 0x025b6,),  # Black Right-pointing Triangle
        (0x025c0, 0x025c0,),  # Black Left-pointing Triangle
        (0x025fb, 0x025fc,),  # White Medium Square     ..Black Medium Square
        (0x02600, 0x02604,),  # Black Sun With Rays     ..Comet
        (0x0260e, 0x0260e,),  # Black Telephone
        (0x02611, 0x02611,),  # Ballot Box With Check
        (0x02618, 0x02618,),  # Shamrock
        (0x0261d, 0x0261d,),  # White Up Pointing Index
        (0x02620, 0x02620,),  # Skull And Crossbones
        (0x02622, 0x02623,),  # Radioactive Sign        ..Biohazard Sign
        (0x02626, 0x02626,),  # Orthodox Cross
        (0x0262a, 0x0262a,),  # Star And Crescent
        (0x0262e, 0x0262f,),  # Peace Symbol            ..Yin Yang
        (0x02638, 0x0263a,),  # Wheel Of Dharma         ..White Smiling Face
        (0x02640, 0x02640,),  # Female Sign
        (0x02642, 0x02642,),  # Male Sign
        (0x0265f, 0x02660,),  # Black Chess Pawn        ..Black Spade Suit
        (0x02663, 0x02663,),  # Black Club Suit
        (0x02665, 0x02666,),  # Black Heart Suit        ..Black Diamond Suit
        (0x02668, 0x02668,),  # Hot Springs
        (0x0267b, 0x0267b,),  # Black Universal Recycling Symbol
        (0x0267e, 0x0267e,),  # Permanent Paper Sign
        (0x02692, 0x02692,),  # Hammer And Pick
        (0x02694, 0x02697,),  # Crossed Swords          ..Alembic
        (0x02699, 0x02699,),  # Gear
        (0x0269b, 0x0269c,),  # Atom Symbol             ..Fleur-de-lis
        (0x026a0, 0x026a0,),  # Warning Sign
        (0x026a7, 0x026a7,),  # Male With Stroke And Male And Female Sign
        (0x026b0, 0x026b1,),  # Coffin                  ..Funeral Urn
        (0x026c8, 0x026c8,),  # Thunder Cloud And Rain
        (0x026cf, 0x026cf,),  # Pick
        (0x026d1, 0x026d1,),  # Helmet With White Cross
        (0x026d3, 0x026d3,),  # Chains
        (0x026e9, 0x026e9,),  # Shinto Shrine
        (0x026f0, 0x026f1,),  # Mountain                ..Umbrella On Ground
        (0x026f4, 0x026f4,),  # Ferry
        (0x026f7, 0x026f9,),  # Skier                   ..Person With Ball
        (0x02702, 0x02702,),  # Black Scissors
        (0x02708, 0x02709,),  # Airplane                ..Envelope
        (0x0270c, 0x0270d,),  # Victory Hand            ..Writing Hand
        (0x0270f, 0x0270f,),  # Pencil
        (0x02712, 0x02712,),  # Black Nib
        (0x02714, 0x02714,),  # Heavy Check Mark
        (0x02716, 0x02716,),  # Heavy Multiplication X
        (0x0271d, 0x0271d,),  # Latin Cross
        (0x02721, 0x02721,),  # Star Of David
        (0x02733, 0x02734,),  # Eight Spoked Asterisk   ..Eight Pointed Black Star
        (0x02744, 0x02744,),  # Snowflake
        (0x02747, 0x02747,),  # Sparkle
        (0x02763, 0x02764,),  # Heavy Heart Exclamation ..Heavy Black Heart
        (0x027a1, 0x027a1,),  # Black Rightwards Arrow
        (0x02934, 0x02935,),  # Arrow Pointing Rightward..Arrow Pointing Rightward
        (0x02b05, 0x02b07,),  # Leftwards Black Arrow   ..Downwards Black Arrow
        (0x1f170, 0x1f171,),  # Negative Squared Latin C..Negative Squared Latin C
        (0x1f17e, 0x1f17f,),  # Negative Squared Latin C..Negative Squared Latin C
        (0x1f321, 0x1f321,),  # Thermometer
        (0x1f324, 0x1f32c,),  # White Sun With Small Clo..Wind Blowing Face
        (0x1f336, 0x1f336,),  # Hot Pepper
        (0x1f37d, 0x1f37d,),  # Fork And Knife With Plate
        (0x1f396, 0x1f397,),  # Military Medal          ..Reminder Ribbon
        (0x1f399, 0x1f39b,),  # Studio Microphone       ..Control Knobs
        (0x1f39e, 0x1f39f,),  # Film Frames             ..Admission Tickets
        (0x1f3cb, 0x1f3ce,),  # Weight Lifter           ..Racing Car
        (0x1f3d4, 0x1f3df,),  # Snow Capped Mountain    ..Stadium
        (0x1f3f3, 0x1f3f3,),  # Waving White Flag
        (0x1f3f5, 0x1f3f5,),  # Rosette
        (0x1f3f7, 0x1f3f7,),  # Label
        (0x1f43f, 0x1f43f,),  # Chipmunk
        (0x1f441, 0x1f441,),  # Eye
        (0x1f4fd, 0x1f4fd,),  # Film Projector
        (0x1f549, 0x1f54a,),  # Om Symbol               ..Dove Of Peace
        (0x1f56f, 0x1f570,),  # Candle                  ..Mantelpiece Clock
        (0x1f573, 0x1f579,),  # Hole                    ..Joystick
        (0x1f587, 0x1f587,),  # Linked Paperclips
        (0x1f58a, 0x1f58d,),  # Lower Left Ballpoint Pen..Lower Left Crayon
        (0x1f590, 0x1f590,),  # Raised Hand With Fingers Splayed
        (0x1f5a5, 0x1f5a5,),  # Desktop Computer
        (0x1f5a8, 0x1f5a8,),  # Printer
        (0x1f5b1, 0x1f5b2,),  # Three Button Mouse      ..Trackball
        (0x1f5bc, 0x1f5bc,),  # Frame With Picture
        (0x1f5c2, 0x1f5c4,),  # Card Index Dividers     ..File Cabinet
        (0x1f5d1, 0x1f5d3,),  # Wastebasket             ..Spiral Calendar Pad
        (0x1f5dc, 0x1f5de,),  # Compression             ..Rolled-up Newspaper
        (0x1f5e1, 0x1f5e1,),  # Dagger Knife
        (0x1f5e3, 0x1f5e3,),  # Speaking Head In Silhouette
        (0x1f5e8, 0x1f5e8,),  # Left Speech Bubble
        (0x1f5ef, 0x1f5ef,),  # Right Anger Bubble
        (0x1f5f3, 0x1f5f3,),  # Ballot Box With Ballot
        (0x1f5fa, 0x1f5fa,),  # World Map
        (0x1f6cb, 0x1f6cb,),  # Couch And Lamp
        (0x1f6cd, 0x1f6cf,),  # Shopping Bags           ..Bed
        (0x1f6e0, 0x1f6e5,),  # Hammer And Wrench       ..Motor Boat
        (0x1f6e9, 0x1f6e9,),  # Small Airplane
        (0x1f6f0, 0x1f6f0,),  # Satellite
        (0x1f6f3, 0x1f6f3,),  # Passenger Ship
    ),
}

VS16_OVERRIDES: dict[str, dict[str, tuple[tuple[int, int], ...]]] = {
    'alacritty': _SET_VS16_OVERRIDES_F48531B2,
    'apple_terminal': _SET_VS16_OVERRIDES_F48531B2,
    'contour': _SET_VS16_OVERRIDES_F48531B2,
    'iterm2': _SET_VS16_OVERRIDES_82FD018F,
    'mlterm': _SET_VS16_OVERRIDES_F48531B2,
    'pterm': _SET_VS16_OVERRIDES_F48531B2,
    'st': _SET_VS16_OVERRIDES_F48531B2,
    'terminology': _SET_VS16_OVERRIDES_F48531B2,
    'urxvt': _SET_VS16_OVERRIDES_F48531B2,
    'vte': _SET_VS16_OVERRIDES_F48531B2,
    'wezterm': _SET_VS16_OVERRIDES_F48531B2,
    'xterm': _SET_VS16_OVERRIDES_F48531B2,
    'xterm.js': _SET_VS16_OVERRIDES_F48531B2,
}

# For terminals: rio
_SET_VS15_OVERRIDES_0F19A03D: dict[str, tuple[tuple[int, int], ...]] = {
    'wider': (
        (0x023eb, 0x023ec,),  # Black Up-pointing Double..Black Down-pointing Doub
        (0x023f0, 0x023f0,),  # Alarm Clock
        (0x026ce, 0x026ce,),  # Ophiuchus
        (0x02705, 0x02705,),  # White Heavy Check Mark
        (0x0270a, 0x0270b,),  # Raised Fist             ..Raised Hand
        (0x02728, 0x02728,),  # Sparkles
        (0x0274c, 0x0274c,),  # Cross Mark
        (0x0274e, 0x0274e,),  # Negative Squared Cross Mark
        (0x02754, 0x02755,),  # White Question Mark Orna..White Exclamation Mark O
        (0x02795, 0x02797,),  # Heavy Plus Sign         ..Heavy Division Sign
        (0x027b0, 0x027b0,),  # Curly Loop
        (0x027bf, 0x027bf,),  # Double Curly Loop
    ),
}

# For terminals: bobcat
_SET_VS15_OVERRIDES_72B9888B: dict[str, tuple[tuple[int, int], ...]] = {
    'wider': (
        (0x03030, 0x03030,),  # Wavy Dash
        (0x0303d, 0x0303d,),  # Part Alternation Mark
        (0x03297, 0x03297,),  # Circled Ideograph Congratulation
        (0x03299, 0x03299,),  # Circled Ideograph Secret
        (0x1f202, 0x1f202,),  # Squared Katakana Sa
        (0x1f237, 0x1f237,),  # Squared Cjk Unified Ideograph-6708
    ),
}

# For terminals: warp
_SET_VS15_OVERRIDES_D32653C3: dict[str, tuple[tuple[int, int], ...]] = {
    'wider': (
        (0x0231a, 0x0231b,),  # Watch                   ..Hourglass
        (0x023e9, 0x023ec,),  # Black Right-pointing Dou..Black Down-pointing Doub
        (0x023f0, 0x023f0,),  # Alarm Clock
        (0x023f3, 0x023f3,),  # Hourglass With Flowing Sand
        (0x025fd, 0x025fe,),  # White Medium Small Squar..Black Medium Small Squar
        (0x02614, 0x02615,),  # Umbrella With Rain Drops..Hot Beverage
        (0x02648, 0x02653,),  # Aries                   ..Pisces
        (0x0267f, 0x0267f,),  # Wheelchair Symbol
        (0x02693, 0x02693,),  # Anchor
        (0x026a1, 0x026a1,),  # High Voltage Sign
        (0x026aa, 0x026ab,),  # Medium White Circle     ..Medium Black Circle
        (0x026bd, 0x026be,),  # Soccer Ball             ..Baseball
        (0x026c4, 0x026c5,),  # Snowman Without Snow    ..Sun Behind Cloud
        (0x026ce, 0x026ce,),  # Ophiuchus
        (0x026d4, 0x026d4,),  # No Entry
        (0x026ea, 0x026ea,),  # Church
        (0x026f2, 0x026f3,),  # Fountain                ..Flag In Hole
        (0x026f5, 0x026f5,),  # Sailboat
        (0x026fa, 0x026fa,),  # Tent
        (0x026fd, 0x026fd,),  # Fuel Pump
        (0x02705, 0x02705,),  # White Heavy Check Mark
        (0x0270a, 0x0270b,),  # Raised Fist             ..Raised Hand
        (0x02728, 0x02728,),  # Sparkles
        (0x0274c, 0x0274c,),  # Cross Mark
        (0x0274e, 0x0274e,),  # Negative Squared Cross Mark
        (0x02753, 0x02755,),  # Black Question Mark Orna..White Exclamation Mark O
        (0x02757, 0x02757,),  # Heavy Exclamation Mark Symbol
        (0x02795, 0x02797,),  # Heavy Plus Sign         ..Heavy Division Sign
        (0x027b0, 0x027b0,),  # Curly Loop
        (0x027bf, 0x027bf,),  # Double Curly Loop
        (0x02b1b, 0x02b1c,),  # Black Large Square      ..White Large Square
        (0x02b50, 0x02b50,),  # White Medium Star
        (0x02b55, 0x02b55,),  # Heavy Large Circle
        (0x1f004, 0x1f004,),  # Mahjong Tile Red Dragon
        (0x1f30d, 0x1f30f,),  # Earth Globe Europe-afric..Earth Globe Asia-austral
        (0x1f315, 0x1f315,),  # Full Moon Symbol
        (0x1f31c, 0x1f31c,),  # Last Quarter Moon With Face
        (0x1f378, 0x1f378,),  # Cocktail Glass
        (0x1f393, 0x1f393,),  # Graduation Cap
        (0x1f3a7, 0x1f3a7,),  # Headphone
        (0x1f3ac, 0x1f3ae,),  # Clapper Board           ..Video Game
        (0x1f3c2, 0x1f3c2,),  # Snowboarder
        (0x1f3c4, 0x1f3c4,),  # Surfer
        (0x1f3c6, 0x1f3c6,),  # Trophy
        (0x1f3ca, 0x1f3ca,),  # Swimmer
        (0x1f3e0, 0x1f3e0,),  # House Building
        (0x1f3ed, 0x1f3ed,),  # Factory
        (0x1f408, 0x1f408,),  # Cat
        (0x1f415, 0x1f415,),  # Dog
        (0x1f41f, 0x1f41f,),  # Fish
        (0x1f426, 0x1f426,),  # Bird
        (0x1f442, 0x1f442,),  # Ear
        (0x1f446, 0x1f449,),  # White Up Pointing Backha..White Right Pointing Bac
        (0x1f44d, 0x1f44e,),  # Thumbs Up Sign          ..Thumbs Down Sign
        (0x1f453, 0x1f453,),  # Eyeglasses
        (0x1f46a, 0x1f46a,),  # Family
        (0x1f47d, 0x1f47d,),  # Extraterrestrial Alien
        (0x1f4a3, 0x1f4a3,),  # Bomb
        (0x1f4b0, 0x1f4b0,),  # Money Bag
        (0x1f4b3, 0x1f4b3,),  # Credit Card
        (0x1f4bb, 0x1f4bb,),  # Personal Computer
        (0x1f4bf, 0x1f4bf,),  # Optical Disc
        (0x1f4cb, 0x1f4cb,),  # Clipboard
        (0x1f4da, 0x1f4da,),  # Books
        (0x1f4df, 0x1f4df,),  # Pager
        (0x1f4e4, 0x1f4e6,),  # Outbox Tray             ..Package
        (0x1f4ea, 0x1f4ed,),  # Closed Mailbox With Lowe..Open Mailbox With Lowere
        (0x1f4f7, 0x1f4f7,),  # Camera
        (0x1f4f9, 0x1f4fb,),  # Video Camera            ..Radio
        (0x1f508, 0x1f508,),  # Speaker
        (0x1f50d, 0x1f50d,),  # Left-pointing Magnifying Glass
        (0x1f512, 0x1f513,),  # Lock                    ..Open Lock
        (0x1f550, 0x1f567,),  # Clock Face One Oclock   ..Clock Face Twelve-thirty
        (0x1f610, 0x1f610,),  # Neutral Face
        (0x1f687, 0x1f687,),  # Metro
        (0x1f68d, 0x1f68d,),  # Oncoming Bus
        (0x1f691, 0x1f691,),  # Ambulance
        (0x1f694, 0x1f694,),  # Oncoming Police Car
        (0x1f698, 0x1f698,),  # Oncoming Automobile
        (0x1f6ad, 0x1f6ad,),  # No Smoking Symbol
        (0x1f6b2, 0x1f6b2,),  # Bicycle
        (0x1f6b9, 0x1f6ba,),  # Mens Symbol             ..Womens Symbol
        (0x1f6bc, 0x1f6bc,),  # Baby Symbol
    ),
}

# For terminals: alacritty, apple_terminal, contour, extraterm, iterm2, konsole, mlterm, pterm, st, terminology, urxvt, vte, wezterm, xterm, xterm.js
_SET_VS15_OVERRIDES_EC2D40AC: dict[str, tuple[tuple[int, int], ...]] = {
    'wider': (
        (0x0231a, 0x0231b,),  # Watch                   ..Hourglass
        (0x023e9, 0x023ec,),  # Black Right-pointing Dou..Black Down-pointing Doub
        (0x023f0, 0x023f0,),  # Alarm Clock
        (0x023f3, 0x023f3,),  # Hourglass With Flowing Sand
        (0x025fd, 0x025fe,),  # White Medium Small Squar..Black Medium Small Squar
        (0x02614, 0x02615,),  # Umbrella With Rain Drops..Hot Beverage
        (0x02648, 0x02653,),  # Aries                   ..Pisces
        (0x0267f, 0x0267f,),  # Wheelchair Symbol
        (0x02693, 0x02693,),  # Anchor
        (0x026a1, 0x026a1,),  # High Voltage Sign
        (0x026aa, 0x026ab,),  # Medium White Circle     ..Medium Black Circle
        (0x026bd, 0x026be,),  # Soccer Ball             ..Baseball
        (0x026c4, 0x026c5,),  # Snowman Without Snow    ..Sun Behind Cloud
        (0x026ce, 0x026ce,),  # Ophiuchus
        (0x026d4, 0x026d4,),  # No Entry
        (0x026ea, 0x026ea,),  # Church
        (0x026f2, 0x026f3,),  # Fountain                ..Flag In Hole
        (0x026f5, 0x026f5,),  # Sailboat
        (0x026fa, 0x026fa,),  # Tent
        (0x026fd, 0x026fd,),  # Fuel Pump
        (0x02705, 0x02705,),  # White Heavy Check Mark
        (0x0270a, 0x0270b,),  # Raised Fist             ..Raised Hand
        (0x02728, 0x02728,),  # Sparkles
        (0x0274c, 0x0274c,),  # Cross Mark
        (0x0274e, 0x0274e,),  # Negative Squared Cross Mark
        (0x02753, 0x02755,),  # Black Question Mark Orna..White Exclamation Mark O
        (0x02757, 0x02757,),  # Heavy Exclamation Mark Symbol
        (0x02795, 0x02797,),  # Heavy Plus Sign         ..Heavy Division Sign
        (0x027b0, 0x027b0,),  # Curly Loop
        (0x027bf, 0x027bf,),  # Double Curly Loop
        (0x02b1b, 0x02b1c,),  # Black Large Square      ..White Large Square
        (0x02b50, 0x02b50,),  # White Medium Star
        (0x02b55, 0x02b55,),  # Heavy Large Circle
        (0x03030, 0x03030,),  # Wavy Dash
        (0x0303d, 0x0303d,),  # Part Alternation Mark
        (0x03297, 0x03297,),  # Circled Ideograph Congratulation
        (0x03299, 0x03299,),  # Circled Ideograph Secret
        (0x1f004, 0x1f004,),  # Mahjong Tile Red Dragon
        (0x1f202, 0x1f202,),  # Squared Katakana Sa
        (0x1f21a, 0x1f21a,),  # Squared Cjk Unified Ideograph-7121
        (0x1f22f, 0x1f22f,),  # Squared Cjk Unified Ideograph-6307
        (0x1f237, 0x1f237,),  # Squared Cjk Unified Ideograph-6708
        (0x1f30d, 0x1f30f,),  # Earth Globe Europe-afric..Earth Globe Asia-austral
        (0x1f315, 0x1f315,),  # Full Moon Symbol
        (0x1f31c, 0x1f31c,),  # Last Quarter Moon With Face
        (0x1f378, 0x1f378,),  # Cocktail Glass
        (0x1f393, 0x1f393,),  # Graduation Cap
        (0x1f3a7, 0x1f3a7,),  # Headphone
        (0x1f3ac, 0x1f3ae,),  # Clapper Board           ..Video Game
        (0x1f3c2, 0x1f3c2,),  # Snowboarder
        (0x1f3c4, 0x1f3c4,),  # Surfer
        (0x1f3c6, 0x1f3c6,),  # Trophy
        (0x1f3ca, 0x1f3ca,),  # Swimmer
        (0x1f3e0, 0x1f3e0,),  # House Building
        (0x1f3ed, 0x1f3ed,),  # Factory
        (0x1f408, 0x1f408,),  # Cat
        (0x1f415, 0x1f415,),  # Dog
        (0x1f41f, 0x1f41f,),  # Fish
        (0x1f426, 0x1f426,),  # Bird
        (0x1f442, 0x1f442,),  # Ear
        (0x1f446, 0x1f449,),  # White Up Pointing Backha..White Right Pointing Bac
        (0x1f44d, 0x1f44e,),  # Thumbs Up Sign          ..Thumbs Down Sign
        (0x1f453, 0x1f453,),  # Eyeglasses
        (0x1f46a, 0x1f46a,),  # Family
        (0x1f47d, 0x1f47d,),  # Extraterrestrial Alien
        (0x1f4a3, 0x1f4a3,),  # Bomb
        (0x1f4b0, 0x1f4b0,),  # Money Bag
        (0x1f4b3, 0x1f4b3,),  # Credit Card
        (0x1f4bb, 0x1f4bb,),  # Personal Computer
        (0x1f4bf, 0x1f4bf,),  # Optical Disc
        (0x1f4cb, 0x1f4cb,),  # Clipboard
        (0x1f4da, 0x1f4da,),  # Books
        (0x1f4df, 0x1f4df,),  # Pager
        (0x1f4e4, 0x1f4e6,),  # Outbox Tray             ..Package
        (0x1f4ea, 0x1f4ed,),  # Closed Mailbox With Lowe..Open Mailbox With Lowere
        (0x1f4f7, 0x1f4f7,),  # Camera
        (0x1f4f9, 0x1f4fb,),  # Video Camera            ..Radio
        (0x1f508, 0x1f508,),  # Speaker
        (0x1f50d, 0x1f50d,),  # Left-pointing Magnifying Glass
        (0x1f512, 0x1f513,),  # Lock                    ..Open Lock
        (0x1f550, 0x1f567,),  # Clock Face One Oclock   ..Clock Face Twelve-thirty
        (0x1f610, 0x1f610,),  # Neutral Face
        (0x1f687, 0x1f687,),  # Metro
        (0x1f68d, 0x1f68d,),  # Oncoming Bus
        (0x1f691, 0x1f691,),  # Ambulance
        (0x1f694, 0x1f694,),  # Oncoming Police Car
        (0x1f698, 0x1f698,),  # Oncoming Automobile
        (0x1f6ad, 0x1f6ad,),  # No Smoking Symbol
        (0x1f6b2, 0x1f6b2,),  # Bicycle
        (0x1f6b9, 0x1f6ba,),  # Mens Symbol             ..Womens Symbol
        (0x1f6bc, 0x1f6bc,),  # Baby Symbol
    ),
}

VS15_OVERRIDES: dict[str, dict[str, tuple[tuple[int, int], ...]]] = {
    'alacritty': _SET_VS15_OVERRIDES_EC2D40AC,
    'apple_terminal': _SET_VS15_OVERRIDES_EC2D40AC,
    'bobcat': _SET_VS15_OVERRIDES_72B9888B,
    'contour': _SET_VS15_OVERRIDES_EC2D40AC,
    'extraterm': _SET_VS15_OVERRIDES_EC2D40AC,
    'iterm2': _SET_VS15_OVERRIDES_EC2D40AC,
    'konsole': _SET_VS15_OVERRIDES_EC2D40AC,
    'mlterm': _SET_VS15_OVERRIDES_EC2D40AC,
    'pterm': _SET_VS15_OVERRIDES_EC2D40AC,
    'rio': _SET_VS15_OVERRIDES_0F19A03D,
    'st': _SET_VS15_OVERRIDES_EC2D40AC,
    'terminology': _SET_VS15_OVERRIDES_EC2D40AC,
    'urxvt': _SET_VS15_OVERRIDES_EC2D40AC,
    'vte': _SET_VS15_OVERRIDES_EC2D40AC,
    'warp': _SET_VS15_OVERRIDES_D32653C3,
    'wezterm': _SET_VS15_OVERRIDES_EC2D40AC,
    'xterm': _SET_VS15_OVERRIDES_EC2D40AC,
    'xterm.js': _SET_VS15_OVERRIDES_EC2D40AC,
}

# For terminals: alacritty
_SET_NARROW_OVERRIDES_19FF3EBB: dict[str, tuple[tuple[int, int], ...]] = {
    'wider': (
        (0x017a4, 0x017a4,),  # Khmer Independent Vowel Qaa
        (0x017d8, 0x017d8,),  # Khmer Sign Beyyal
    ),
    'narrow_zeroer': (
        (0x000ad, 0x000ad,),  # Soft Hyphen
        (0x00605, 0x00605,),  # Arabic Number Mark Above
        (0x0070f, 0x0070f,),  # Syriac Abbreviation Mark
        (0x00890, 0x00891,),  # Arabic Pound Mark Above ..Arabic Piastre Mark Abov
        (0x008e2, 0x008e2,),  # Arabic Disputed End Of Ayah
        (0x00d4e, 0x00d4e,),  # Malayalam Letter Dot Reph
        (0x0a8fa, 0x0a8fa,),  # Devanagari Caret
        (0x0ff9e, 0x0ff9f,),  # Halfwidth Katakana Voice..Halfwidth Katakana Semi-
        (0x111c2, 0x111c3,),  # Sharada Sign Jihvamuliya..Sharada Sign Upadhmaniya
        (0x1193f, 0x1193f,),  # Dives Akuru Prefixed Nasal Sign
        (0x11941, 0x11941,),  # Dives Akuru Initial Ra
        (0x11a84, 0x11a89,),  # Soyombo Sign Jihvamuliya..Soyombo Cluster-initial
        (0x11d46, 0x11d46,),  # Masaram Gondi Repha
        (0x11f02, 0x11f02,),  # Kawi Sign Repha
    ),
}

# For terminals: konsole, wezterm
_SET_NARROW_OVERRIDES_3E5607A0: dict[str, tuple[tuple[int, int], ...]] = {
    'narrow_zeroer': (
        (0x000ad, 0x000ad,),  # Soft Hyphen
        (0x00600, 0x00605,),  # Arabic Number Sign      ..Arabic Number Mark Above
        (0x006dd, 0x006dd,),  # Arabic End Of Ayah
        (0x0070f, 0x0070f,),  # Syriac Abbreviation Mark
        (0x00890, 0x00891,),  # Arabic Pound Mark Above ..Arabic Piastre Mark Abov
        (0x008e2, 0x008e2,),  # Arabic Disputed End Of Ayah
        (0x110bd, 0x110bd,),  # Kaithi Number Sign
        (0x110cd, 0x110cd,),  # Kaithi Number Sign Above
    ),
}

# For terminals: kitty
_SET_NARROW_OVERRIDES_4F7FBF42: dict[str, tuple[tuple[int, int], ...]] = {
    'wider': (
        (0x0261d, 0x0261d,),  # White Up Pointing Index
        (0x026f9, 0x026f9,),  # Person With Ball
        (0x0270c, 0x0270d,),  # Victory Hand            ..Writing Hand
        (0x1f3cb, 0x1f3cc,),  # Weight Lifter           ..Golfer
        (0x1f574, 0x1f575,),  # Man In Business Suit Lev..Sleuth Or Spy
        (0x1f590, 0x1f590,),  # Raised Hand With Fingers Splayed
    ),
    'narrow_zeroer': (
        (0x000ad, 0x000ad,),  # Soft Hyphen
        (0x00600, 0x00605,),  # Arabic Number Sign      ..Arabic Number Mark Above
        (0x006dd, 0x006dd,),  # Arabic End Of Ayah
        (0x0070f, 0x0070f,),  # Syriac Abbreviation Mark
        (0x00890, 0x00891,),  # Arabic Pound Mark Above ..Arabic Piastre Mark Abov
        (0x008e2, 0x008e2,),  # Arabic Disputed End Of Ayah
        (0x0ff9e, 0x0ff9f,),  # Halfwidth Katakana Voice..Halfwidth Katakana Semi-
        (0x110bd, 0x110bd,),  # Kaithi Number Sign
        (0x110cd, 0x110cd,),  # Kaithi Number Sign Above
    ),
}

# For terminals: xterm.js
_SET_NARROW_OVERRIDES_763C1244: dict[str, tuple[tuple[int, int], ...]] = {
    'wider': (
        (0x1f93b, 0x1f93b,),  # Modern Pentathlon
        (0x1f946, 0x1f946,),  # Rifle
    ),
    'narrow_zeroer': (
        (0x00600, 0x00605,),  # Arabic Number Sign      ..Arabic Number Mark Above
        (0x006dd, 0x006dd,),  # Arabic End Of Ayah
        (0x0070f, 0x0070f,),  # Syriac Abbreviation Mark
        (0x008e2, 0x008e2,),  # Arabic Disputed End Of Ayah
        (0x110bd, 0x110bd,),  # Kaithi Number Sign
        (0x110cd, 0x110cd,),  # Kaithi Number Sign Above
    ),
}

# For terminals: foot, pterm, rio, vte
_SET_NARROW_OVERRIDES_8B501630: dict[str, tuple[tuple[int, int], ...]] = {
    'narrow_zeroer': (
        (0x00600, 0x00605,),  # Arabic Number Sign      ..Arabic Number Mark Above
        (0x006dd, 0x006dd,),  # Arabic End Of Ayah
        (0x0070f, 0x0070f,),  # Syriac Abbreviation Mark
        (0x00890, 0x00891,),  # Arabic Pound Mark Above ..Arabic Piastre Mark Abov
        (0x008e2, 0x008e2,),  # Arabic Disputed End Of Ayah
        (0x110bd, 0x110bd,),  # Kaithi Number Sign
        (0x110cd, 0x110cd,),  # Kaithi Number Sign Above
    ),
}

# For terminals: st, urxvt, xterm
_SET_NARROW_OVERRIDES_9BC01E8D: dict[str, tuple[tuple[int, int], ...]] = {
    'wider': (
        (0x03248, 0x0324f,),  # Circled Number Ten On Bl..Circled Number Eighty On
    ),
}

# For terminals: bobcat
_SET_NARROW_OVERRIDES_B19CC1BB: dict[str, tuple[tuple[int, int], ...]] = {
    'narrow_zeroer': (
        (0x00890, 0x00891,),  # Arabic Pound Mark Above ..Arabic Piastre Mark Abov
        (0x008e2, 0x008e2,),  # Arabic Disputed End Of Ayah
        (0x110bd, 0x110bd,),  # Kaithi Number Sign
        (0x110cd, 0x110cd,),  # Kaithi Number Sign Above
    ),
}

# For terminals: iterm2
_SET_NARROW_OVERRIDES_C5500A15: dict[str, tuple[tuple[int, int], ...]] = {
    'narrow_zeroer': (
        (0x000ad, 0x000ad,),  # Soft Hyphen
    ),
}

# For terminals: warp
_SET_NARROW_OVERRIDES_FDEEB1C7: dict[str, tuple[tuple[int, int], ...]] = {
    'wider': (
        (0x017a4, 0x017a4,),  # Khmer Independent Vowel Qaa
        (0x017d8, 0x017d8,),  # Khmer Sign Beyyal
    ),
    'narrow_zeroer': (
        (0x000ad, 0x000ad,),  # Soft Hyphen
        (0x00605, 0x00605,),  # Arabic Number Mark Above
        (0x0070f, 0x0070f,),  # Syriac Abbreviation Mark
        (0x00890, 0x00891,),  # Arabic Pound Mark Above ..Arabic Piastre Mark Abov
        (0x008e2, 0x008e2,),  # Arabic Disputed End Of Ayah
        (0x00d4e, 0x00d4e,),  # Malayalam Letter Dot Reph
        (0x0a8fa, 0x0a8fa,),  # Devanagari Caret
        (0x0ff9e, 0x0ff9f,),  # Halfwidth Katakana Voice..Halfwidth Katakana Semi-
        (0x111c2, 0x111c3,),  # Sharada Sign Jihvamuliya..Sharada Sign Upadhmaniya
        (0x1193f, 0x1193f,),  # Dives Akuru Prefixed Nasal Sign
        (0x11941, 0x11941,),  # Dives Akuru Initial Ra
        (0x11a3a, 0x11a3a,),  # Zanabazar Square Cluster-initial Letter Ra
        (0x11a84, 0x11a89,),  # Soyombo Sign Jihvamuliya..Soyombo Cluster-initial
        (0x11d46, 0x11d46,),  # Masaram Gondi Repha
        (0x11f02, 0x11f02,),  # Kawi Sign Repha
    ),
}

NARROW_OVERRIDES: dict[str, dict[str, tuple[tuple[int, int], ...]]] = {
    'alacritty': _SET_NARROW_OVERRIDES_19FF3EBB,
    'bobcat': _SET_NARROW_OVERRIDES_B19CC1BB,
    'foot': _SET_NARROW_OVERRIDES_8B501630,
    'iterm2': _SET_NARROW_OVERRIDES_C5500A15,
    'kitty': _SET_NARROW_OVERRIDES_4F7FBF42,
    'konsole': _SET_NARROW_OVERRIDES_3E5607A0,
    'pterm': _SET_NARROW_OVERRIDES_8B501630,
    'rio': _SET_NARROW_OVERRIDES_8B501630,
    'st': _SET_NARROW_OVERRIDES_9BC01E8D,
    'urxvt': _SET_NARROW_OVERRIDES_9BC01E8D,
    'vte': _SET_NARROW_OVERRIDES_8B501630,
    'warp': _SET_NARROW_OVERRIDES_FDEEB1C7,
    'wezterm': _SET_NARROW_OVERRIDES_3E5607A0,
    'xterm': _SET_NARROW_OVERRIDES_9BC01E8D,
    'xterm.js': _SET_NARROW_OVERRIDES_763C1244,
}

__all__ = ['WIDE_OVERRIDES', 'SRI_OVERRIDES', 'SFZ_OVERRIDES', 'VS16_OVERRIDES', 'VS15_OVERRIDES', 'NARROW_OVERRIDES']
